@@ -4,6 +4,7 @@ from ..utils.io import *
 from ..utils.print import *
 from ..constants import *
 
+@measure_time(info, "Loot tables generated")
 def main(config: dict):
 	database: dict[str,dict] = config["database"]
 	external_database: dict[str,dict] = config["external_database"]
@@ -34,8 +35,6 @@ def main(config: dict):
 				set_components["components"][f"minecraft:{k}"] = v
 		loot_table["pools"][0]["entries"][0]["functions"] = [set_components]
 		write_to_file(f"{config['build_datapack']}/data/{namespace}/loot_table/external/{ns}/{item}.json", super_json_dump(loot_table, max_level = 9))
-	
-	info("Made loot tables for every item")
 
 
 	# Loot tables for items with crafting recipes
@@ -52,7 +51,6 @@ def main(config: dict):
 			for result_count in results:
 				loot_table = {"pools":[{"rolls":1,"entries":[{"type":"minecraft:loot_table","value":f"{namespace}:i/{item}","functions":[{"function":"minecraft:set_count","count":result_count}]}]}]}
 				write_to_file(f"{config['build_datapack']}/data/{namespace}/loot_table/i/{item}_x{result_count}.json", super_json_dump(loot_table, max_level = -1), overwrite = True)
-	info("Multiple counts loot tables made for every item with crafting recipes")
 
 	# Second loot table for the manual (if present)
 	if "manual" in database:
@@ -83,5 +81,4 @@ def main(config: dict):
 		joined_content = ",".join(chest_contents)
 		chests.append(f'give @s chest[container=[{joined_content}],custom_name=\'{{"text":"Chest [{i+1}/{total_chests}]","color":"yellow"}}\',lore=["{lore}"]]')
 	write_to_function(config, f"{namespace}:_give_all", "\n" + "\n\n".join(chests) + "\n\n")
-	info("Give all function successfully made")
 
