@@ -2,6 +2,7 @@
 # Imports
 from .utils.io import *
 from .utils.print import *
+from .constants import *
 import shutil
 
 def main(config: dict):
@@ -16,13 +17,12 @@ def main(config: dict):
 	read_initial_files([config["build_datapack"], config["build_resource_pack"]])
 
 	# Setup pack.mcmeta for the datapack
-	pack_mcmeta = {"pack":{"pack_format": config["datapack_format"], "description": config["description"]}, "id": config["namespace"]}
+	pack_mcmeta = {"pack":{"pack_format": DATAPACK_FORMAT, "description": config["description"]}, "id": config["namespace"]}
 	write_to_file(f"{config['build_datapack']}/pack.mcmeta", super_json_dump(pack_mcmeta))
 
 	# Setup pack.mcmeta for the resource pack
-	if config.get("resource_pack_format"):
-		pack_mcmeta = {"pack":{"pack_format": config["resource_pack_format"], "description": config["description"]}, "id": config["namespace"]}
-		write_to_file(f"{config['build_resource_pack']}/pack.mcmeta", super_json_dump(pack_mcmeta))
+	pack_mcmeta = {"pack":{"pack_format": RESOURCE_PACK_FORMAT, "description": config["description"]}, "id": config["namespace"]}
+	write_to_file(f"{config['build_resource_pack']}/pack.mcmeta", super_json_dump(pack_mcmeta))
 
 	# Convert textures names if needed
 	if config.get('textures_files'):
@@ -41,7 +41,7 @@ def main(config: dict):
 				if k in file:
 					new_name = new_name.replace(k, v)
 			if new_name != file:
-				os.rename(f"{config['textures_folder']}/{file}", f"{config['textures_folder']}/{new_name}")
+				os.rename(f"{config['assets_folder']}/textures/{file}", f"{config['assets_folder']}/textures/{new_name}")
 				info(f"Renamed {file} to {new_name}")
 
 	# Print total time
